import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

from release_one.validation import validate_tank
from release_one.decomp import decompose_tank

store = 166
tank = 1

# load tank data
dat = pd.read_csv(f'./data/tank/kt{store}_tank_history.csv')
dat = dat[dat['tank_id'] == tank]

# validate sales data
dat = dat.to_dict(orient="records")
tank_dat = format_tank(dat)

# decompose tank data into GAM curves
decomp = decompose_tank(tank_dat)

# visualize seasonality
plt.close()
sns.set()
fig = sns.lineplot(y=decomp.daily, x=range(0, 48)).set_title(f'KT{store}: tank number {tank}')
plt.savefig(fname=f'./figures/decompose/tank/KT{store}{tank}_daily_decomp.png')
plt.show()




import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt

from release_one.validation import *

# tank sticking data, formatted
dat = pd.read_csv('./data/demo/raw/kt141_tank_history.csv')
dat = dat.loc[(dat.tank_id == 1)]
dat = dat.drop(dat.columns[4], axis=1)
dat = dat.to_dict(orient="records")
tank_dat = format_tank(dat)

# sales data, formatted
dat = pd.read_csv('./data/sales/KT1442_sales.csv',
                  usecols=[1, 2, 3, 4, 5])
sales_dat = dat.to_dict(orient="records")
sales_dat = format_sales(sales_dat)



# adjusting tank data histories - test cases
# normal tank data
full_tank = tank_dat.iloc[-432:]
full_tank.reset_index(inplace=True, drop=True)

out = validate_tank(tank_data=full_tank, sales_data=sales_dat)
plt.close()

sns.set()
fig = sns.lineplot(x=out.index, y=out.actual, color = 'blue', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.estimated, color = 'red', alpha=0.7)
fig.set_title('data validation example 1 (normal tank)')
fig.legend(['actuals', 'estimated'])
# plt.savefig(fname=f'./figures/data_validation_ex1.png')
plt.show()


# older tank data
old_tank = tank_dat.iloc[-432-200:-200]
old_tank.reset_index(inplace=True, drop=True)

out = validate_tank(tank_data=old_tank, sales_data=sales_dat)
out

plt.close()
sns.set()
fig = sns.lineplot(x=out.index, y=out.actual, color='blue', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.estimated, color='red', alpha=0.7)
fig.set_title('data validation example 2 (older tank)')
fig.legend(['unadjusted', 'adjusted'])
# plt.savefig(fname=f'./figures/data_validation_ex2.png')
plt.show()




# half a tank worth of data
half_tank = tank_dat.iloc[-250:]
half_tank.reset_index(inplace=True, drop=True)

out = validate_tank(tank_data=half_tank, sales_data=sales_dat)
out

plt.close()
sns.set()
fig = sns.lineplot(x=out.index, y=out.actual, color = 'blue', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.estimated, color = 'red', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.output, color='green', alpha=0.7)
fig.set_title('data validation example 3 (half tank)')
fig.legend(['unadjusted', 'adjusted', 'output'])
plt.savefig(fname=f'./figures/data_validation_ex3.png')
plt.show()


# missing data
missing_tank = pd.concat([tank_dat.iloc[-300:-200], tank_dat.iloc[-50:]], ignore_index=True)
missing_tank.reset_index(inplace=True, drop=True)

out = validate_tank(tank_data=missing_tank, sales_data=sales_dat)
out

plt.close()
sns.set()
fig = sns.lineplot(x=out.index, y=out.actual, color = 'blue', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.estimated, color = 'red', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.output, color='green', alpha=0.7)
fig.set_title('data validation example 4')
fig.legend(['unadjusted', 'adjusted', 'output'])
# plt.savefig(fname=f'./figures/data_validation_ex4.png')
plt.show()


no_tank = tank_dat.iloc[0:0]

out = validate_tank(tank_data=no_tank, sales_data=sales_dat)
out
forecast_near(out,



plt.close()
sns.set()
fig = sns.lineplot(x=out.index, y=out.actual, color = 'blue', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.estimated, color = 'red', alpha=0.7)
fig = sns.lineplot(x=out.index, y=out.output, color='green', alpha=0.7)
fig.set_title('data validation example 5 (no data) - obv not working')
fig.legend(['unadjusted', 'adjusted', 'output'])
# plt.savefig(fname=f'./figures/data_validation_ex5.png')
plt.show()


import numpy as np
import pandas as pd

from release_one.events import standard_events, remove_event_factor

generic_sales = pd.DataFrame({'ds': pd.date_range(start='2020-01-01',
                                                  end='2020-12-31', freq='1D'),
                              'y': np.repeat(100, 366)})

generic_tank = pd.DataFrame({'ds': pd.date_range(start='2020-12-24',
                                               end='2021-01-02', freq='30min'),
                           'y': np.repeat(100, 433)})

# sales history

sns.set()
sns.lineplot(x=generic_sales.ds, y=generic_sales.y)
plt.show()

test = remove_event_factor(generic_sales, standard_events)
test

sns.set()
sns.lineplot(x=test.ds, y=test.y)
plt.show()


# tank history

sns.set()
sns.lineplot(x=generic_tank.ds, y=generic_tank.y)
plt.show()

test2 = remove_event_factor(generic_tank, standard_events)
test2

sns.set()
sns.lineplot(x=test2.ds, y=test2.y)
plt.show()


import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
from fbprophet import Prophet

from release_one.validation import format_tank, format_sales

dat = pd.read_csv(f'data/tank/kt144_tank_history.csv', usecols=range(1, 6))
dat = dat.loc[dat['tank_id'] == 1]
dat = dat.to_dict(orient="records")
tank_dat = format_tank(dat)
tank_dat

m = Prophet(changepoint_prior_scale=0.05,
            daily_seasonality=True,
            weekly_seasonality=True,
            yearly_seasonality=True,
            seasonality_mode='multiplicative')
mod = m.fit(tank_dat)
future = m.make_future_dataframe(periods=150, freq='1D')
forecast = m.predict(future)

m.plot_components(forecast)
plt.show()



dat = pd.read_csv('/Users/fisherankney/workspace/forecaster_local/data/sales/KT1042_sales.csv')
dat = dat.to_dict(orient="records")
sales_dat = format_sales(dat)

m = Prophet(changepoint_prior_scale=0.05,
            daily_seasonality=False,
            weekly_seasonality=False,
            yearly_seasonality=True,
            seasonality_mode='multiplicative')
mod = m.fit(sales_dat)
future = m.make_future_dataframe(periods=150, freq='1D')
forecast = m.predict(future)

m.plot_components(forecast)
plt.show()



import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

from release_one.validation import format_sales
from release_one.decomp import decompose_sales

# select store and tank
store = 144
tank = 2

# load sales data
dat = pd.read_csv(f'./data/sales/KT{store}{tank}_sales.csv',
                  usecols=range(1, 6))
tank_type = dat.tank_type.iloc[-1]

# validate sales data
dat = dat.to_dict(orient="records")
sales_dat = format_sales(dat)

# decompose sales data into GAM curves
decomp = decompose_sales(sales_dat)

# visualize yearly / weekly seasonality
plt.close()
sns.set()
fig, axs = plt.subplots(2)
fig = sns.lineplot(y=decomp[0], x=range(len(decomp[0])), ax=axs[0]).set_title(f'KT{store}: Fuel type {tank_type}')
fig = sns.lineplot(y=decomp[1], x=range(len(decomp[1])), ax=axs[1])
plt.savefig(fname=f'./figures/decompose/sales/KT{store}{tank}_season_decomp.png')
plt.show()




